==> go.php?file=RaidSlackCheck5.427.zip: RaidSlackCheck/Localization/localization-ruRU.lua <==
﻿if GetLocale() == "ruRU" then


function rsclocalel()

rscchatlist1				= "рейд"
rscchatlist2				= "объявление рейду"
rscchatlist3				= "офицер"
rscchatlist4				= "группа"
rscchatlist5				= "гильдия"
rscchatlist6				= "сказать"
rscchatlist7				= "крикнуть"
rscchatlist8				= "только себе"
rsclocrlslak				= "сообщ. слак Рейд Лидера"
rsclocpot2				= "0 выбранных зелий"
rsclocrep1				= "Сообщить в чат:"
rsclocnotinc				= "вне боя (препоты)"
rscloclastf				= "последний бой"
rsclocallpot				= "все зелья"
rsclocpot3				= "НЕ пили зелья"
rsclocfight1				= "посл. бой"
rsclocfight2				= "пред. бой"
rsclocfight3				= "бой"
rsclocpot4				= "Все выпили зелье"
rsclocpot5				= "Инфо по зелью"
rsclocpot6				= "0 зелий: "
rsclocpot7				= "пили все"
rsclocpot8				= "Пили но другое зелье: "
rsclocpot9				= "Все из выпивших пили только выбранное зелье."
rsclocpot10				= "Кто пил"
rsclocpot11				= "Кто НЕ пил"
rsclocpot12				= "Зелья перед последним боем:"
rsclocpot13				= "Пили зелья перед посл. боем"
rsclocpot14				= "Перед последним боем - никто не пил зелья."
rsclocpot15				= "Пили зелья перед последним боем только"
rsclocpot16				= "НЕ пили зелья перед посл. боем"
rsclocpot17				= "Никто не пил зелья"
rsclocpot18				= "Зелья выпили"
rscloccolor				= "цветные ники"
rscbuttonreset				= "Сбросить"
rscsec					= "сек."
rscmin					= "минут"
rscmanualsend				= "отправить вручную:"
rscbuffspart1				= "Модуль проверяет через"
rscbuffspart2				= "после воскрешения выбраные баффы на игроке и сообщает их отсутствие в чат и приват бафферам, после - проверяет их еще раз через"
rscbuffspart3				= "Можно вписать через запятую ответственных за баффы, тогда если они присутствуют в рейде и живы - приват будет отправлен только им при первой проверке, в противном случае - всем бафферам."
rscparton3				= "ВКЛЮЧЕНО"
rscpartanons31				= "сообщать в чат при 1 проверке"
rscpartanons32				= "сообщать в чат при 2 проверке"
rscpartanons33				= "сообщать в приват при 1 проверке"
rscpartanons34				= "сообщать в приват при 2 проверке"
rscpartanons35				= "сообщать даже без статуса помощника"
rscpartwhobuff1				= "Ответственные за бафф:"
psfpotchecklocal			= "Проверка зелий"
psfpotchecklocalt2			= "Проверка настоев и еды"
psfpotchecklocalt3			= "Обн. баффов в бою"
psfpotchecklocalt322			= "Проверка обновления баффов в бою после 'возрождения'"
rscbuffnameslitnew1			= "5% статов"
rscbuffnameslitnew2			= "Стамина"
rscbuffnameslitnew3			= "Защ. от тьмы"
rscbuffnameslitnew4			= "Интеллект"
rscbuffnameslitnew5			= "Благословение могущества"
rscreleasedtxt1				= "был возрожден"
rscreleasedtxt1f			= "была возрождена"
rscreleasedtxt2				= "назад"
rscreleasedtxt3				= "НЕТ"
rscreleasedtxt4				= "ДО СИХ ПОР НЕТ"
rscreleasedtxt5				= "вторая проверка"
rscreleasedtxt6				= "но на нем ДО СИХ ПОР НЕТ"
rscreleasedtxt6f			= "но на ней ДО СИХ ПОР НЕТ"
rscreleasedtxt7				= "но на нем НЕТ"
rscreleasedtxt7f			= "но на ней НЕТ"
rscflasktext1				= "Кроме обычной проверки настоев и еды - данный модуль имеет уникальные возможности автоматической проверки и вывода информации перед началом боя с боссом, запуске 'Проверки готовности' или таймера 'Атаки' через аддон PhoenixStyle, но не чаще чем раз в 50 сек. кроме начала боя."
rscsend					= "Отправить"
rscreloadbutton				= "Обновить"
rscflasktextc11				= "сообщать в начале боя с боссом"
rscflasktextc12				= "сообщать при запуске таймера 'Атаки'"
rscflasktextc13				= "сообщать при запуске 'Проверки готовности'"
rscflasktextc14				= "отправлять приваты при авто-проверке"
rscflasktextc15				= "проверять еду"
rscflasktext2				= "чат для авто-проверки:"
rscflasktext3				= "Проверяю первые"
rscflasktext4				= "Только один эликсир"
rscflasktext5				= "Нет настоя"
rscflasktext6				= "ни у кого нет"
rscflasktext7				= "Нет баффа еды"
rscflasktext8				= "Бафф еды только у"
rscflasktext9				= "Не проверены"
rscflasktext10				= "У всех есть баффы настоев и еды."
rscflasktext11				= "У всех есть баффы настоев."
rscflasktext12				= "Данные не доступны. Много непровереных игроков"
rscflasktxtgroup5			= "групп"
rscflasktxtgroup2			= "группы"
rscflaskwhisptxt1			= "RSC > На Вас нет баффа еды!"
rscflaskwhisptxt2			= "RSC > На Вас бафф только от 1 эликсира!"
rscflaskwhisptxt3			= "RSC > Вы забыли выпить настой!"
rscflaskwhisptxt4			= "RSC > На Вас нет баффа еды и всего 1 эликсир!"
rscflaskwhisptxt5			= "RSC > На Вас нет баффа от настоя и еды!"
rscpartanons36				= "при исп. эликсиров - требовать наличие 2, а не 1"
rscflasktext1part2			= "Бафф не учитывается если до его окончания менее |cffff0000%s|r мин."
rscbuttonztext1				= "Добавить тек. зону"
rscbuttonztext2				= "Удалить тек. зону"
rscbuttonztext3				= "Показать список"
rscbuttonztext4				= "Очистить список"
rscaddonnotworkinz			= "Аддон включен для некоторых зон:"
rsczonereport1				= "Аддон включен в следующих зонах: "
rsczonereport2				= "Аддон теперь будет работать в зоне: "
rsczonereport3				= "Аддон больше не будет работать в: "
rsczonereport5				= "Список зон, в которых аддон работает, успешно очищен! Проверки временно приостановлены."
rsczonereport6				= "список пуст"
rsczonereport7				= "|cffff0000Ошибка!|r Текущая зона уже находится в списке!"
rsczonereport8				= "|cffff0000Ошибка!|r Текущая зона отсутствует в списке!"
rsczonereport9				= "Что бы сбросить список зон - нажмите на кнопку |cffff0000еще раз|r в течении 10 сек!"
rscflaskwhisptxt11			= "RSC > На Вас заканчивается бафф еды."
rscflaskwhisptxt33			= "RSC > Ваш бафф настоя подходит к концу, обновите!"
rscflaskwhisptxt40			= "RSC > На Вас нет баффа еды и заканчивается бафф настоя!"
rscflaskwhisptxt44			= "RSC > На Вас заканчивается бафф еды и всего 1 эликсир!"
rscflaskwhisptxt55			= "RSC > На Вас нет баффа настоя и заканчивается бафф еды!"
rscflaskwhisptxt56			= "RSC > На Вас заканчиваются баффы от настоя и еды."
rsconlybossfigtloc			= "только бои с боссом"
rsconlybossfig1				= "Теперь использование зелий проверяется только в боях с боссом"
rsconlybossfig2				= "Теперь использование зелий проверяется во всех боях"
rscflasktext555				= "СТАРЫЙ настой"
rsctablereptxt1				= "сообщать когда кто-то ставит пир"
rsctablereptxt2				= "сообщать когда кто-то ставит котел с настоями"
rsctablereptxt3				= "сообщать когда кто-то ставит ремонтного робота"
rsctablereptxt4				= "сообщать когда кто-то ставит источник душ"
rsctableused1				= "готовит пир!"
rsctableused2				= "поставил котел с настоями!"
rsctableused3				= "поставил ремонтного робота!"
rsctableused4				= "ставит источник душ!"
rscfoodstillthere			= "уже готовый пир ждет тебя"
rsclocpoths17				= "Никто не использовал Камень здоровья"
rsclocpoths172				= "ВСЕ использовали Камень здоровья"
rsclocpoths18				= "Камень здоровья использовали"
rsclocpoths182				= "> НЕ < исп. камень здоровья"
rscwhousehstext				= "Исп. камень здоровья"
rscwhousehstext2			= "НЕ исп. камень здоровья"
rscprepots            = "Препоты"
rscadditionalstat1    = "Выносл"
rscadditionalstat2    = "Инт"
rscadditionalstat3    = "Дух"
rscadditionalstat4    = "Ловк"
rscadditionalstat5    = "Сила"
rscadditionalstatbonus = "бонус"
rscpartanonsfoodadd        = "учитывать %s еду"
rsceating				= "кушает"


end

end

==> go.php?file=RaidSlackCheck6.001.zip: RaidSlackCheck/Localization/localization-ruRU.lua <==
﻿if GetLocale() == "ruRU" then


function rsclocalel()

rscchatlist1				= "рейд"
rscchatlist2				= "объявление рейду"
rscchatlist3				= "офицер"
rscchatlist4				= "группа"
rscchatlist5				= "гильдия"
rscchatlist6				= "сказать"
rscchatlist7				= "крикнуть"
rscchatlist8				= "только себе"
rsclocrlslak				= "сообщ. слак Рейд Лидера"
rsclocpot2				= "0 выбранных зелий"
rsclocrep1				= "Сообщить в чат:"
rsclocnotinc				= "вне боя (препоты)"
rscloclastf				= "последний бой"
rsclocallpot				= "все зелья"
rsclocpot3				= "НЕ пили зелья"
rsclocfight1				= "посл. бой"
rsclocfight2				= "пред. бой"
rsclocfight3				= "бой"
rsclocpot4				= "Все выпили зелье"
rsclocpot5				= "Инфо по зелью"
rsclocpot6				= "0 зелий: "
rsclocpot7				= "пили все"
rsclocpot8				= "Пили но другое зелье: "
rsclocpot9				= "Все из выпивших пили только выбранное зелье."
rsclocpot10				= "Кто пил"
rsclocpot11				= "Кто НЕ пил"
rsclocpot12				= "Зелья перед последним боем:"
rsclocpot13				= "Пили зелья перед посл. боем"
rsclocpot14				= "Перед последним боем - никто не пил зелья."
rsclocpot15				= "Пили зелья перед последним боем только"
rsclocpot16				= "НЕ пили зелья перед посл. боем"
rsclocpot17				= "Никто не пил зелья"
rsclocpot18				= "Зелья выпили"
rscloccolor				= "цветные ники"
rscbuttonreset				= "Сбросить"
rscsec					= "сек."
rscmin					= "минут"
rscmanualsend				= "отправить вручную:"
rscbuffspart1				= "Модуль проверяет через"
rscbuffspart2				= "после воскрешения выбраные баффы на игроке и сообщает их отсутствие в чат и приват бафферам, после - проверяет их еще раз через"
rscbuffspart3				= "Можно вписать через запятую ответственных за баффы, тогда если они присутствуют в рейде и живы - приват будет отправлен только им при первой проверке, в противном случае - всем бафферам."
rscparton3				= "ВКЛЮЧЕНО"
rscpartanons31				= "сообщать в чат при 1 проверке"
rscpartanons32				= "сообщать в чат при 2 проверке"
rscpartanons33				= "сообщать в приват при 1 проверке"
rscpartanons34				= "сообщать в приват при 2 проверке"
rscpartanons35				= "сообщать даже без статуса помощника"
rscpartwhobuff1				= "Ответственные за бафф:"
psfpotchecklocal			= "Проверка зелий"
psfpotchecklocalt2			= "Проверка настоев и еды"
psfpotchecklocalt3			= "Обн. баффов в бою"
psfpotchecklocalt322			= "Проверка обновления баффов в бою после 'возрождения'"
rscbuffnameslitnew1			= "5% статов"
rscbuffnameslitnew2			= "Стамина"
rscbuffnameslitnew3			= "Защ. от тьмы"
rscbuffnameslitnew4			= "Интеллект"
rscbuffnameslitnew5			= "Благословение могущества"
rscreleasedtxt1				= "был возрожден"
rscreleasedtxt1f			= "была возрождена"
rscreleasedtxt2				= "назад"
rscreleasedtxt3				= "НЕТ"
rscreleasedtxt4				= "ДО СИХ ПОР НЕТ"
rscreleasedtxt5				= "вторая проверка"
rscreleasedtxt6				= "но на нем ДО СИХ ПОР НЕТ"
rscreleasedtxt6f			= "но на ней ДО СИХ ПОР НЕТ"
rscreleasedtxt7				= "но на нем НЕТ"
rscreleasedtxt7f			= "но на ней НЕТ"
rscflasktext1				= "Кроме обычной проверки настоев и еды - данный модуль имеет уникальные возможности автоматической проверки и вывода информации перед началом боя с боссом, запуске 'Проверки готовности' или таймера 'Атаки' через аддон PhoenixStyle, но не чаще чем раз в 50 сек. кроме начала боя."
rscsend					= "Отправить"
rscreloadbutton				= "Обновить"
rscflasktextc11				= "сообщать в начале боя с боссом"
rscflasktextc12				= "сообщать при запуске таймера 'Атаки'"
rscflasktextc13				= "сообщать при запуске 'Проверки готовности'"
rscflasktextc14				= "отправлять приваты при авто-проверке"
rscflasktextc15				= "проверять еду"
rscflasktext2				= "чат для авто-проверки:"
rscflasktext3				= "Проверяю первые"
rscflasktext4				= "Только один эликсир"
rscflasktext5				= "Нет настоя"
rscflasktext6				= "ни у кого нет"
rscflasktext7				= "Нет баффа еды"
rscflasktext8				= "Бафф еды только у"
rscflasktext9				= "Не проверены"
rscflasktext10				= "У всех есть баффы настоев и еды."
rscflasktext11				= "У всех есть баффы настоев."
rscflasktext12				= "Данные не доступны. Много непровереных игроков"
rscflasktxtgroup5			= "групп"
rscflasktxtgroup2			= "группы"
rscflaskwhisptxt1			= "RSC > На Вас нет баффа еды!"
rscflaskwhisptxt2			= "RSC > На Вас бафф только от 1 эликсира!"
rscflaskwhisptxt3			= "RSC > Вы забыли выпить настой!"
rscflaskwhisptxt4			= "RSC > На Вас нет баффа еды и всего 1 эликсир!"
rscflaskwhisptxt5			= "RSC > На Вас нет баффа от настоя и еды!"
rscpartanons36				= "при исп. эликсиров - требовать наличие 2, а не 1"
rscflasktext1part2			= "Бафф не учитывается если до его окончания менее |cffff0000%s|r мин."
rscbuttonztext1				= "Добавить тек. зону"
rscbuttonztext2				= "Удалить тек. зону"
rscbuttonztext3				= "Показать список"
rscbuttonztext4				= "Очистить список"
rscaddonnotworkinz			= "Аддон включен для некоторых зон:"
rsczonereport1				= "Аддон включен в следующих зонах: "
rsczonereport2				= "Аддон теперь будет работать в зоне: "
rsczonereport3				= "Аддон больше не будет работать в: "
rsczonereport5				= "Список зон, в которых аддон работает, успешно очищен! Проверки временно приостановлены."
rsczonereport6				= "список пуст"
rsczonereport7				= "|cffff0000Ошибка!|r Текущая зона уже находится в списке!"
rsczonereport8				= "|cffff0000Ошибка!|r Текущая зона отсутствует в списке!"
rsczonereport9				= "Что бы сбросить список зон - нажмите на кнопку |cffff0000еще раз|r в течении 10 сек!"
rscflaskwhisptxt11			= "RSC > На Вас заканчивается бафф еды."
rscflaskwhisptxt33			= "RSC > Ваш бафф настоя подходит к концу, обновите!"
rscflaskwhisptxt40			= "RSC > На Вас нет баффа еды и заканчивается бафф настоя!"
rscflaskwhisptxt44			= "RSC > На Вас заканчивается бафф еды и всего 1 эликсир!"
rscflaskwhisptxt55			= "RSC > На Вас нет баффа настоя и заканчивается бафф еды!"
rscflaskwhisptxt56			= "RSC > На Вас заканчиваются баффы от настоя и еды."
rsconlybossfigtloc			= "только бои с боссом"
rsconlybossfig1				= "Теперь использование зелий проверяется только в боях с боссом"
rsconlybossfig2				= "Теперь использование зелий проверяется во всех боях"
rscflasktext555				= "СТАРЫЙ настой"
rsctablereptxt1				= "сообщать когда кто-то ставит пир"
rsctablereptxt2				= "сообщать когда кто-то ставит котел с настоями"
rsctablereptxt3				= "сообщать когда кто-то ставит ремонтного робота"
rsctablereptxt4				= "сообщать когда кто-то ставит источник душ"
rsctableused1				= "готовит пир!"
rsctableused2				= "поставил котел с настоями!"
rsctableused3				= "поставил ремонтного робота!"
rsctableused4				= "ставит источник душ!"
rscfoodstillthere			= "уже готовый пир ждет тебя"
rsclocpoths17				= "Никто не использовал Камень здоровья"
rsclocpoths172				= "ВСЕ использовали Камень здоровья"
rsclocpoths18				= "Камень здоровья использовали"
rsclocpoths182				= "> НЕ < исп. камень здоровья"
rscwhousehstext				= "Исп. камень здоровья"
rscwhousehstext2			= "НЕ исп. камень здоровья"
rscprepots            = "Препоты"
rscadditionalstat1    = "Выносл"
rscadditionalstat2    = "Инт"
rscadditionalstat3    = "Дух"
rscadditionalstat4    = "Ловк"
rscadditionalstat5    = "Сила"
rscadditionalstatbonus = "бонус"
rscpartanonsfoodadd        = "учитывать %s еду"
rsceating				= "ест"
rsceating2				= "ест"

end

end
